![logo](logo.png)

# aerosol-functions
A collection of methods to analyze and visualize atmospheric aerosol data.

Install using `pip install aerosol-functions`

See the [documentation](https://jlpl.github.io/aerosol-functions/)
